<h2 class="display-2">Authenticate your Work in your ORCID record</h2>
<p>{{org_name}} would like to write a work information to your ORCID record</p>
<p>If you would like to allow this, or if you don't currently have an ORCID record but would like to <br/>
create one and have this Work information added to it, please click on the following link:</p>
<p><a href="{{ invitation_url }}">{{ invitation_url }}</a><p>
Once you click this link, you'll be taken to ORCID to sign in to, or create, your ORCID record.
Once you've granted permission, you'll be automatically taken to the Hub.
Note no further action from you is needed.
In the next minute or so, the work information will be shown in your ORCID record with {{org_name}} as the source.
</p>
